@@ -5,6 +5,7 @@ from adaptor.objectives.backtranslation import BackTranslation, BackTranslator
 from adaptor.objectives.classification import TokenClassification
 from adaptor.objectives.denoising import DenoisingObjective
 from adaptor.objectives.objective_base import Objective
+from adaptor.objectives.question_answering import ExtractiveQA
 from adaptor.objectives.seq2seq import Sequence2Sequence
 from utils import paths, test_base_models
 
@@ -21,7 +22,7 @@ def assert_module_objective_ok(lang_module: LangModule, objective: Objective, sp
     outputs = lang_module(**dataset_sample)
 
     # loss computation test, possible label smoothing is performed by Adapter
-    loss = objective.compute_loss(outputs, dataset_sample["labels"], split)
+    loss = objective.compute_loss(outputs, dataset_sample["labels"], dataset_sample, split)
 
     # check that retrieved loss has a backward_fn
     loss.backward()
@@ -123,3 +124,15 @@ def test_supervised_seq2seq_objective_mbart():
                                   target_lang_id=test_base_models["translation_multi"]["test_tgt_lang"])
 
     assert_module_objective_ok(lang_module, objective)
+
+
+def test_supervised_QA_objective():
+    lang_module = LangModule(test_base_models["extractive_QA"])
+
+    objective = ExtractiveQA(lang_module,
+                             texts_or_path=paths["texts"]["QA"],
+                             text_pair_or_path=paths["text_pair"]["QA"],
+                             labels_or_path=paths["labels"]["QA"],
+                             batch_size=4)
+
+    assert_module_objective_ok(lang_module, objective)
