@@ -5,12 +5,17 @@ paths = {
         "ner": "mock_data/supervised_texts.txt",
         "classification": "mock_data/supervised_texts.txt",
         "translation": "mock_data/seq2seq_sources.txt",
-        "unsup": "mock_data/domain_unsup.txt"
+        "unsup": "mock_data/domain_unsup.txt",
+        "QA": "mock_data/QA_questions.txt"
     },
     "labels": {
         "ner": "mock_data/supervised_texts_token_labels.txt",
         "classification": "mock_data/supervised_texts_sequence_labels.txt",
-        "translation": "mock_data/seq2seq_targets.txt"
+        "translation": "mock_data/seq2seq_targets.txt",
+        "QA": "mock_data/QA_answers.txt"
+    },
+    "text_pair": {
+        "QA": "mock_data/QA_contexts.txt"
     }
 }
 
@@ -21,7 +26,8 @@ test_base_models = {
             "test_src_lang": "en_XX",
             "test_tgt_lang": "cs_CZ"},
     "token_classification": "bert-base-multilingual-cased",
-    "sequence_classification": "bert-base-multilingual-cased"
+    "sequence_classification": "bert-base-multilingual-cased",
+    "extractive_QA": "Unbabel/xlm-roberta-comet-small"
 }
 
 training_arguments = AdaptationArguments(output_dir="adaptation_output_dir",
